@@ -220,8 +220,8 @@ def format_autolab_json(data, indent=None):
 
             d = {'passed': pass_}
             if not pass_:
-                d['hint'] = val['stderr']
-                # d['hint'] = "<br>".join( val['stderr'].strip().splitlines() )
+                # d['hint'] = val['stderr']
+                d['hint'] = "<br>".join( val['stderr'].strip().splitlines() )
 
 
             rs[item_name] = d
@@ -230,9 +230,10 @@ def format_autolab_json(data, indent=None):
         totals[title] = qs['obtained']
         stages.append(title)
         pres[title] = rs
-    stages.append("Total")
+    summary_key = "Summary"
+    stages.append(summary_key)
     pres['stages'] = stages
-    pres['Summary'] = totals
+    pres[summary_key] = totals
     # rs = {
     #     "_presentation": "semantic",
     #     "stages": ["Build", "Test", "Timing"],
